======
Export
======

Export DataFrame data to other formats:

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    DataFrame.__array__
    DataFrame.__arrow_c_stream__
    DataFrame.__dataframe__
    DataFrame.to_arrow
    DataFrame.to_dict
    DataFrame.to_dicts
    DataFrame.to_init_repr
    DataFrame.to_jax
    DataFrame.to_numpy
    DataFrame.to_pandas
    DataFrame.to_struct
    DataFrame.to_torch
